@@ -27,22 +27,20 @@ __all__ = [
     'cnot',
     'cz',
     'cy',
+    'swap',
+    'sswap',
+    'cswap',
+    'toffoli',
+    'multicnot',
+    'multixcnot',
     'rx',
     'ry',
     'rz',
     'rxx',
     'ryy',
     'rzz',
-    'zz',
     'rzx',
-    'zx',
-    'swap',
-    'sswap',
-    'cswap',
-    'toffoli',
     'phaseshift',
-    'p',
-    'cp',
     'rot',
     'multirz',
     'crx',
@@ -52,25 +50,32 @@ __all__ = [
     'u1',
     'u2',
     'u3',
-    'u',
     'cu1',
     'cu2',
     'cu3',
-    'cu',
     'qubitunitary',
     'qubitunitaryfast',
     'qubitunitarystrict',
-    'multicnot',
-    'multixcnot',
+    'single_excitation',
+    'h',
+    'sh',
     'x',
     'y',
     'z',
+    'xx',
+    'yy',
     'zz',
+    'zx',
     'cx',
     'ccnot',
     'ccx',
+    'u',
+    'cu',
+    'p',
+    'cp',
+    'cr',
+    'cphase',
     'reset',
-    'single_excitation'
 ]
 
 
